Save-to-DB
----------
This library makes it easy to store data from any source into a database.

**Installation**::

    pip install Save-to-DB

----

**Warning:** This library works only with Python 3.

----

|

**Documentation and tutorial:**

- On the Internet: https://save-to-db.readthedocs.io
- Download for offline reading:
  https://readthedocs.org/projects/save-to-db/downloads/


**Project repository:** https://bitbucket.org/mikhail-makovenko/save-to-db